@@ -2,6 +2,7 @@ import click
 
 from fixieai.cli.auth import oauth_flow
 from fixieai.cli.auth import user_config
+from fixieai.client import client
 
 
 def validate_not_authed(ctx, param, force):
@@ -13,7 +14,10 @@ def validate_not_authed(ctx, param, force):
     try:
         config = user_config.load_config()
         if config.fixie_api_key is not None:
-            click.echo("Already authenticated. Set --force to force re-authentication.")
+            username = _get_username(config.fixie_api_key)
+            click.echo("Already authenticated as ", nl=False)
+            click.secho(username, fg="green", nl=False, bold=True)
+            click.echo(". Set --force to force re-authentication.")
             ctx.exit()
     except FileNotFoundError:
         pass
@@ -36,3 +40,13 @@ def auth():
 
     config.fixie_api_key = fixie_api_token
     user_config.save_config(config)
+
+    username = _get_username(fixie_api_token)
+    click.secho("Success! You're authenticated as ", fg="green", bold=True, nl=False)
+    click.secho(username, fg="magenta", nl=False, bold=True)
+    click.secho(".")
+
+
+def _get_username(api_key: str) -> str:
+    """Gets the username for an api_key."""
+    return client.FixieClient(api_key).get_current_username()
